@@ -1,8 +1,6 @@
 import requests
 from requests.exceptions import HTTPError
 
-__version__ = "0.1.0"
-
 
 class ArxConnectionError(Exception):
     """
@@ -22,25 +20,25 @@ class Arx:
     CACHE = {}
 
     def __init__(self, uri=None):
-        self.version = __version__
         if uri:
-            self.REPOSITORY_URI = uri
+            self.REPOSITORY_URI = uri.rstrip("/")
 
     def get(self, key=None, default=None, namespace=None):
         if namespace is None:
             namespace = self.DEFAULT_NAMESPACE
 
-        query_url = f"{self.REPOSITORY_URI}/api/v1/{namespace}"
+        query_url = f"{self.REPOSITORY_URI}/api/v1/{namespace}/"
         single = False
         if key is not None:
             single = True
-            query_url += f"/key"
+            query_url += f"{key}/"
 
         try:
             resp = requests.get(query_url)
             resp.raise_for_status()
-            result_json = resp.json()
-            return result_json["value"] if single else result_json
+            if single:
+                return resp.json()["value"]
+            return resp.json()["variables"]
         except HTTPError as exc:
             # print(exc.response.text)
             if exc.response.status_code == 404:
